"""
GuardClaw Phase 1 Demos.

These demos showcase the execution wrapper in action.
"""

from guardclaw.demos.file_operations import FileOperationsDemo
from guardclaw.demos.dangerous_actions import DangerousActionsDemo

__all__ = [
    "FileOperationsDemo",
    "DangerousActionsDemo",
]
